@@ -4,7 +4,7 @@
 """
 """
     split_file_reader
-    Copyright (C) 2021  Xavier Halloran, United States
+    Copyright (C) 2022  Xavier Halloran, United States
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 """
 
 
-__version__ = '0.0.5'
+__version__ = "0.1.0"
 
 import logging
 
@@ -30,6 +30,4 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 from .split_file_reader import SplitFileReader
 
-__all__ = [
-    "SplitFileReader",
-]
+__all__ = ["SplitFileReader"]
