@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """
     split_file_reader
-    Copyright (C) 2021  Xavier Halloran, United States
+    Copyright (C) 2022  Xavier Halloran, United States
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ _STATIONARY = 0
 _FORWARD = 1
 
 
-class SplitFileReader(object):
+class SplitFileReader(io.BytesIO):
     """
     Acts file-like for a list of files opened readably in binary mode.
     Provides `readable`, `writable`, `seekable`, `tellable`.
@@ -75,12 +75,12 @@ class SplitFileReader(object):
     """
 
     def __init__(
-            self,
-            files: typing.List[typing.Union[str, os.PathLike, typing.Any]],
-            mode: str = "rb",
-            stream_only: bool = False,
-            validate_all_readable: bool = False,
-            iter_size: int = 1,
+        self,
+        files: typing.List[typing.Union[str, os.PathLike, typing.Any]],
+        mode: str = "rb",
+        stream_only: bool = False,
+        validate_all_readable: bool = False,
+        iter_size: int = 1,
     ) -> None:
         """
         Creates the file-like object around a series of files.  At return, there will be a single open file descriptor,
@@ -136,10 +136,7 @@ class SplitFileReader(object):
         """
         return self._read(-1)
 
-    def read(
-            self,
-            size: typing.Optional[int] = None,
-    ) -> typing.AnyStr:
+    def read(self, size: typing.Optional[int] = None) -> typing.AnyStr:
         """
         Read the specified amount, making underlying file boundaries invisible to the caller.
 
@@ -196,20 +193,15 @@ class SplitFileReader(object):
         :param buffer:
         :return:
         """
-        m = memoryview(buffer).cast('B')
-        data = self.read(len(m))
+        data = self.read(len(buffer))
         n = len(data)
-        m[:n] = data
+        buffer[:n] = data
         return n
 
     def seekable(self) -> bool:
         return not self._stream_only
 
-    def seek(
-            self,
-            offset: int,
-            whence: int = 0,
-    ) -> int:
+    def seek(self, offset: int, whence: int = 0) -> int:
         """
         Move the file pointer along a file.  May advance over zero or more actual files.
 
@@ -264,7 +256,6 @@ class SplitFileReader(object):
             trace("How far to go: {}".format(how_far_to_go))
             if how_far_to_go == 0:
                 trace("Nowhere to go.")
-                pass
             elif how_far_to_go > 0:
                 self._scan_forward(how_far_to_go)
             elif how_far_to_go < 0:
@@ -290,10 +281,7 @@ class SplitFileReader(object):
         debug("Sought {} Whence {}, currently {}".format(offset, whence, self._told))
         return self.tell()
 
-    def _scan_forward(
-            self,
-            offset: int,
-    ) -> None:
+    def _scan_forward(self, offset: int) -> None:
         """
         Forward seeking is tricky; it is posisble to seek beyond the end of a file, even in read-only mode.  So seek
         immediately to the end of the current file descriptor, and check the distance moved.  If moved too far, back up
@@ -314,7 +302,7 @@ class SplitFileReader(object):
             # Did the seek to the end of the file go too far?
             if moved > remaining:
                 # Overshot the seek forward.  Move backward again.
-                corrective_move = remaining-moved
+                corrective_move = remaining - moved
                 self._current_file_desc.seek(corrective_move, 1)
                 end_pos = self._current_file_desc.tell()
                 moved = end_pos - start_pos
@@ -328,13 +316,13 @@ class SplitFileReader(object):
                 # The generator for advancing file descriptors will ensure the pointer is at the start of the file part
                 if not self._safe_advance_file_desc(_FORWARD):
                     break
-        trace("Out of loop.  Tell: {}  File tell {}:  Current file idx: {}".format(
-            self._told, self._current_file_desc.tell(), self._current_file_desc_idx))
+        trace(
+            "Out of loop.  Tell: {}  File tell {}:  Current file idx: {}".format(
+                self._told, self._current_file_desc.tell(), self._current_file_desc_idx
+            )
+        )
 
-    def _scan_backward(
-            self,
-            offset: int,
-    ) -> None:
+    def _scan_backward(self, offset: int) -> None:
         """
         The backward scan is implemented by moving the file pointer all the way to the front of the current file
         descriptor, and checking if the movement has gone far enough.  If more to go, move to the previous file,
@@ -420,8 +408,9 @@ class SplitFileReader(object):
         :param direction: Backward -1, Stationary 0, Forward 1, or Closing 2.
         :return: Whether or not the _current_file_desc was changed.  False indicates end of file, either end.
         """
-        if (direction == _FORWARD and self._current_file_desc_idx + 1 >= len(self._files)) or \
-                (direction == _BACKWARD and self._current_file_desc_idx <= 0):
+        if (direction == _FORWARD and self._current_file_desc_idx + 1 >= len(self._files)) or (
+            direction == _BACKWARD and self._current_file_desc_idx <= 0
+        ):
             return False
         else:
             self._advance_file_desc(direction)
@@ -477,7 +466,7 @@ class SplitFileReader(object):
                     # No, it's a filename
                     self._filePassed = 0
                     self.filename = file
-                    with open(file, 'rb') as self._current_file_desc:
+                    with open(file, "rb") as self._current_file_desc:
                         debug("Opening new fd on {}".format(file))
                         direction = yield self._current_file_desc
                         debug("Closing fd on {}".format(file))
@@ -586,6 +575,7 @@ class SplitFileReader(object):
 
     def __repr__(self):
         from json import dumps
+
         try:
             # Might be closed, or might be an empty list.
             cfile = dumps(self._files[self._current_file_desc_idx])
@@ -597,12 +587,7 @@ class SplitFileReader(object):
             cdesc = 0
 
         return "<{cls}, {id}: Tell: {tell}, File Desc: {fdesc}, File Name: {fname}, File Tell: {ftell}>".format(
-            cls=self.__class__.__name__,
-            id=hex(id(self)),
-            tell=self.tell(),
-            fdesc=cdesc,
-            fname=cfile,
-            ftell=ctell,
+            cls=self.__class__.__name__, id=hex(id(self)), tell=self.tell(), fdesc=cdesc, fname=cfile, ftell=ctell
         )
 
     """
@@ -664,9 +649,11 @@ class SplitFileReader(object):
         raise IOError("No current file descriptor in use.")
 
     def readline(self, size: int = ...) -> bytes:
-        raise io.UnsupportedOperation("{} cannot decode text, and therefore cannot readline.".format(
-            self.__class__.__name__))
+        raise io.UnsupportedOperation(
+            "{} cannot decode text, and therefore cannot readline.".format(self.__class__.__name__)
+        )
 
     def readlines(self, hint: int = ...) -> typing.List[bytes]:
-        raise io.UnsupportedOperation("{} cannot decode text, and therefore cannot readlines.".format(
-            self.__class__.__name__))
+        raise io.UnsupportedOperation(
+            "{} cannot decode text, and therefore cannot readlines.".format(self.__class__.__name__)
+        )
